package com.bukkit.TJ09;

import java.io.File;
import java.util.HashMap;
import java.util.Timer;
import java.util.Date;

import org.bukkit.entity.Player;
import org.bukkit.Server;
import org.bukkit.event.Event.Priority;
import org.bukkit.event.Event;
import org.bukkit.plugin.PluginDescriptionFile;
import org.bukkit.plugin.PluginLoader;
import org.bukkit.plugin.java.JavaPlugin;
import org.bukkit.plugin.PluginManager;
import org.bukkit.util.config.Configuration;

/**
 * MapMarkers for Bukkit
 *
 * @author TJ09
 */
public class MapMarkers extends JavaPlugin {
	private final MapMarkersPlayerListener playerListener = new MapMarkersPlayerListener(this);
	private final Timer timer = new Timer();
	private final HashMap<Player, Boolean> debugees = new HashMap<Player, Boolean>();
	public final HashMap<Player, Date> lastSeen = new HashMap<Player, Date>();

	public MapMarkers(PluginLoader pluginLoader, Server instance, PluginDescriptionFile desc, File folder, File plugin, ClassLoader cLoader) {
		super(pluginLoader, instance, desc, folder, plugin, cLoader);
	}

	public void onEnable() {
		Configuration config = new Configuration(new File("MapMarkers.yml"));
		config.load();
	
		int interval = config.getInt("saveInterval",3000);
		String outputFile = config.getString("outputFile","world/markers.json");
		String dateFormat = config.getString("dateFormat","yyyyMMdd HH:mm:ss");
		// Start periodically updating stuff.
		timer.scheduleAtFixedRate(new MapMarkersTimerTask(this,outputFile,dateFormat), interval, interval);

		// Register our events
		PluginManager pm = getServer().getPluginManager();
		
		pm.registerEvent(Event.Type.PLAYER_MOVE, playerListener, Priority.Monitor, this);
		pm.registerEvent(Event.Type.PLAYER_LOGIN, playerListener, Priority.Monitor, this);
		pm.registerEvent(Event.Type.PLAYER_QUIT, playerListener, Priority.Monitor, this);
		
		PluginDescriptionFile pdfFile = this.getDescription();
		System.out.println( pdfFile.getName() + " version " + pdfFile.getVersion() + " enabled" );
	}
	public void onDisable() {
		// Stop running.
		timer.cancel();

		// NOTE: All registered events are automatically unregistered when a plugin is disabled
		System.out.println("Unloading "+this.getDescription().getName());
	}
	public boolean isDebugging(final Player player) {
		if (debugees.containsKey(player)) {
			return debugees.get(player);
		} else {
			return false;
		}
	}

	public void setDebugging(final Player player, final boolean value) {
		debugees.put(player, value);
	}
}

